#
# spec file for package python-zope.exceptions
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-zope.exceptions%{psuffix}
Version:        5.1
Release:        1.1
Summary:        Zope Exceptions
License:        ZPL-2.1
Group:          Development/Languages/Python
URL:            https://cheeseshop.python.org/pypi/zope.exceptions
Source:         https://files.pythonhosted.org/packages/source/z/zope.exceptions/zope.exceptions-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-zope.interface
Obsoletes:      %{name}-doc
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module zope.exceptions}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  %{python_module zope.testrunner}
%endif
%python_subpackages

%description
This package contains exception interfaces and implementations which are so
general purpose that they don't belong in Zope application-specific packages.

%prep
%autosetup -p1 -n zope.exceptions-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%python_expand %{_bindir}/zope-testrunner-%{$python_bin_suffix} -vvv --test-path src
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst COPYRIGHT.txt README.rst
%dir %{python_sitelib}/zope/
%{python_sitelib}/zope/exceptions
%{python_sitelib}/zope.exceptions-%{version}*-info
%{python_sitelib}/zope.exceptions-%{version}*-nspkg.pth
%endif

%changelog
* Thu Jun 13 2024 Dirk Müller <dmueller@suse.com>
- update to 5.1:
  * Add support for Python 3.12.
  * Include code from PEP302 loaders in tracebacks
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.1:
  * Fix issue introduced in the last release which is breaking
  * ``HTMLExceptionFormatter`` when using non-str
    ``__traceback_info__``.
  * Drop support for Python 2.7, 3.5, 3.6.
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Jan  6 2023 Dirk Müller <dmueller@suse.com>
- update to 4.6:
  * Catch exceptions in ``formatExceptionOnly``.
  Getting an exception when reporting about a different exception is not helpful.
  On Python 3.11 this is needed for some HTTPErrors.
  * Add official support for Python 3.11.
  * Add official support for Python 3.9 and 3.10.
  * Undo dropping support for Python 3.5.
  * Drop support for running the tests using ``python setup.py test``.
- drop zope.exceptions-pr19+pr21-py310.patch (upstream)
* Sun Dec 19 2021 Ben Greiner <code@bnavigator.de>
- Add zope.exceptions-pr19+pr21-py310.patch
  * gh#zopefoundation/zope.exceptions#21
* Tue Jul 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.4
  * Add support for Python 3.8 and preliminary support for 3.9b4.
  * Drop support for Python 3.4 and 3.5.
* Fri Apr  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.3
  * Add support for Python 3.6 and 3.7.
  * Drop support for Python 3.3.
  * Fix handling of unicode supplemental traceback information on
    Python 2.
- drop *-doc subpackage, use multibuild instead
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Jul  4 2017 jmatejek@suse.com
- drop unneeded _multibuild
* Fri Jun 23 2017 aloisio@gmx.com
- Update to version 4.1.0
  * Drop support for Python 2.6 and 3.2.
  * Make exceptionformatter.extract_stack signature comply with
    traceback.extract_stack
  * Add support for Python 3.5.
  4.0.8:
  * Fixes around TextExceptionFormatter limit: formatException
    and extractStack was cutting the traceback at the bottom, at
    the most interesting point. Now it will cut from the middle.
    Some text about the missing entries will be inserted.
  * Maybe fix for extractStack, it did not detect recursions in
    the frames.
- Split -doc into separate package and put tests there
* Thu Sep  3 2015 toddrme2178@gmail.com
- Disable tests to avoid dependency loop
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.0.7:
  * Added explicit support for Python 3.4.
  * Updated boostrap.py to version 2.2.
- switch the source archive to tar.gz (zip not available)
- remove unzip from BuildRequires
- pass -q to test to avoid spamming the build log
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Jul 29 2013 hpj@urpla.net
- generate documentation in separate -doc file
- enable tests (run tests on source tree)
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
